@@ -304,6 +304,9 @@ parse.envi <- function(m.list) {
   # function
   env <- env[-which(names(env) == "sourcedScripts")]
   env <- env[-which(names(env) == "sourcedScriptTimeStamps")]
+  if ("sourcedScriptHashes" %in% names(env)) {
+    env <- env[-which(names(env) == "sourcedScriptHashes")]
+  }
   
   # Swap rows and columns for clarity and apply name the column
   environment <- t(as.data.frame(env))
@@ -322,8 +325,16 @@ parse.libs <- function(m.list) {
   # add unneeded columns
   libraries <- parse.from.identifier("l", m.list)
   
-  # Pull out columns of info wanted
-  libraries <- libraries[,c("id", "name", "version")]
+  # Pull out columns of info wanted.  The "whereLoaded" column was
+  # added with rdtLite 1.4
+  columns <- colnames(libraries)
+  if ("whereLoaded" %in% columns) {
+  	libraries <- libraries[,c("id", "name", "version", "whereLoaded")]
+  }
+  else {
+    libraries <- libraries[,c("id", "name", "version")]
+    libraries$whereLoaded <- "unknown"
+  }
   return(libraries)
 }
 
@@ -334,16 +345,30 @@ parse.scripts <- function(m.list) {
   env <- m.list$environment
   
   # Put the main script in the table
-  scripts.df <- data.frame (script = env$script[1], timestamp = env$scriptTimeStamp[1],
-      stringsAsFactors = F)
+  scripts.df <- 
+    if ("scriptHash" %in% names(env)) 
+      data.frame (script = env$script[1], 
+                  timestamp = env$scriptTimeStamp[1],
+                  hash = env$scriptHash[1], stringsAsFactors = F)
+    else 
+      data.frame (script = env$script[1], 
+                  timestamp = env$scriptTimeStamp[1],
+                  hash = "", stringsAsFactors = F)
   
   # Grab the sourced script names
   scripts <- env$`sourcedScripts`
   
   if (length(scripts) > 0 && scripts[1] != "") {
     # Append the sourced scripts
-    scripts.df <- rbind (scripts.df, 
-        cbind(script = scripts, timestamp = env$`sourcedScriptTimeStamps`))
+    scripts.df <- 
+      if ("sourcedScriptHashes" %in% names(env)) 
+        rbind (scripts.df, cbind(script = scripts, 
+                                 timestamp = env$`sourcedScriptTimeStamps`, 
+                                 hash = env$`sourcedScriptHashes`))
+      else 
+        rbind (scripts.df, cbind(script = scripts, 
+                                 timestamp = env$`sourcedScriptTimeStamps`, 
+                                 hash = rep("", length(scripts))))
   }
   
   return(scripts.df)
@@ -795,6 +820,17 @@ get.func.lib <- function(prov) {
   } 
 }
 
+get.libs.needed <- function (prov, proc_ids) {
+    func.proc.edges <- prov@func.proc.edges
+    if (nrow (func.proc.edges) == 0) return (vector())
+    func.nodes <- get.func.nodes (prov)
+    print (func.nodes)
+    matching <- func.nodes[func.nodes$activity %in% proc_ids, ]
+    print (matching)
+    return (matching)
+}
+	
+
 #' @rdname access
 #' @return get.input.files returns a data frame containing a subset of the data nodes that correspond to files that are 
 #'   read by the script.  If only.files is False, the data frame contains information about both input files and URLs.
